@@ -1,6 +1,6 @@
-from datetime import timedelta
 from bs4 import BeautifulSoup
 from pycaption import BaseReader, BaseWriter
+from .util import format_timestamp
 
 
 dfxp_base = '''
@@ -214,8 +214,8 @@ class DFXPWriter(BaseWriter):
         return dfxp
 
     def _recreate_p_tag(self, sub, dfxp):
-        start = '0' + str(timedelta(milliseconds=(int(sub[0] / 1000))))[:11]
-        end = '0' + str(timedelta(milliseconds=(int(sub[1] / 1000))))[:11]
+        start = format_timestamp(sub[0])
+        end = format_timestamp(sub[1])
         p = dfxp.new_tag("p", begin=start, end=end)
         p.string = self._recreate_text(sub[2], dfxp)
 
